"""adding permission and last modified

Revision ID: 8fdc843fc202
Revises: 6e7f580ff680
Create Date: 2022-10-17 14:11:33.017738

"""
from alembic import op
import sqlalchemy as sa

from sqlalchemy.dialects import postgresql
from sqlalchemy import engine_from_config
from sqlalchemy.engine import reflection

# revision identifiers, used by Alembic.
revision = "8fdc843fc202"
down_revision = "6e7f580ff680"
branch_labels = None
depends_on = None

def _table_has_column(table, column):
    config = op.get_context().config
    engine = engine_from_config(
        config.get_section(config.config_ini_section), prefix="sqlalchemy."
    )

    insp = reflection.Inspector.from_engine(engine)
    return any(column in col["name"] for col in insp.get_columns(table))


def upgrade():
    permission_enum = postgresql.ENUM(
        "PRIVATE", "GROUP", "PUBLIC", name="readwrite_permission"
    )
    permission_enum.create(op.get_bind())   

    if not _table_has_column("annotation_table_metadata", "write_permission"):
        op.add_column(
            "annotation_table_metadata",
            sa.Column(
                "write_permission",
                postgresql.ENUM("PRIVATE", "GROUP", "PUBLIC", name="readwrite_permission"),
                nullable=True,
            ),
        )
        op.execute("UPDATE annotation_table_metadata SET write_permission = 'PRIVATE'")
        op.alter_column("annotation_table_metadata", "write_permission", nullable=False)

    if not _table_has_column("annotation_table_metadata", "read_permission"):
        op.add_column(
            "annotation_table_metadata",
            sa.Column(
                "read_permission",
                postgresql.ENUM("PRIVATE", "GROUP", "PUBLIC", name="readwrite_permission"),
                nullable=True,
            ),
        )
        op.execute("UPDATE annotation_table_metadata SET read_permission = 'PUBLIC'")
        op.alter_column("annotation_table_metadata", "read_permission", nullable=False)

    if not _table_has_column("annotation_table_metadata", "last_modified"):
        op.add_column(
            "annotation_table_metadata",
            sa.Column("last_modified", sa.DateTime(), nullable=True),
        )

        op.execute("UPDATE annotation_table_metadata SET last_modified = current_timestamp")
        op.alter_column("annotation_table_metadata", "last_modified", nullable=False)
    
def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("annotation_table_metadata", "last_modified")
    op.drop_column("annotation_table_metadata", "read_permission")
    op.drop_column("annotation_table_metadata", "write_permission")
    # ### end Alembic commands ###
